Learn R Programming

uxr (version 0.2.0)

uxr-package: uxr: User Experience Research

Description

Provides convenience functions for user experience research with an emphasis on quantitative user experience testing and reporting. The functions are designed to translate statistical approaches to applied user experience research.

Arguments

Author

Maintainer: Joe Chelladurai joe.chelladurai@yahoo.com (ORCID)

See Also